@@ -13,8 +13,10 @@ c.GERule <- function(..., recursive = FALSE) {
   l = list(...)
   
   ret = l[[1]]
-  for (i in 2:length(l)) {
-    ret = GERule.Concat(ret, l[[i]])
+  if (length(l) > 1) {
+    for (i in 2:length(l)) {
+      ret = GERule.Concat(ret, l[[i]])
+    }
   }
   
   ret
